@@ -25,6 +25,7 @@ def register_views(injector, app):
     from iatoolkit.views.prompt_api_view import PromptApiView
     from iatoolkit.views.history_api_view import HistoryApiView
     from iatoolkit.views.help_content_api_view import HelpContentApiView
+    from iatoolkit.views.profile_api_view import UserLanguageApiView  # <-- Importa la nueva vista
 
     from iatoolkit.views.login_view import LoginView, FinalizeContextView
     from iatoolkit.views.external_login_view import ExternalLoginView, RedeemTokenApiView
@@ -55,6 +56,11 @@ def register_views(injector, app):
         view_func=FinalizeContextView.as_view('finalize_with_token')
     )
 
+    app.add_url_rule(
+        '/api/profile/language',
+        view_func=UserLanguageApiView.as_view('user_language_api')
+    )
+
     # logout
     app.add_url_rule('/<company_short_name>/api/logout',
                      view_func=LogoutApiView.as_view('logout'))
