@@ -27,8 +27,8 @@ class DatabaseManager:
             self._engine = create_engine(
                 database_url,
                 echo=False,
-                pool_size=2,  # per worker
-                max_overflow=3,
+                pool_size=10,  # per worker
+                max_overflow=20,
                 pool_timeout=30,
                 pool_recycle=1800,
                 pool_pre_ping=True,
@@ -77,7 +77,7 @@ class DatabaseManager:
         inspector = inspect(self._engine)
 
         if table_name not in inspector.get_table_names():
-            raise RuntimeError(f"La tabla '{table_name}' no existe en la BD.")
+            raise RuntimeError(f"Table '{table_name}' does not exist.")
 
         if exclude_columns is None:
             exclude_columns = []
