@@ -74,10 +74,6 @@ class ProfileRepo:
         if company:
             if company.parameters != new_company.parameters:
                 company.parameters = new_company.parameters
-            if company.branding != new_company.branding:
-                company.branding = new_company.branding
-            if company.onboarding_cards != new_company.onboarding_cards:
-                company.onboarding_cards = new_company.onboarding_cards
         else:
             # Si la compañía no existe, la añade a la sesión.
             self.session.add(new_company)
